diff --git a/src/Menus.cpp b/src/Menus.cpp
index 2e030d8..7333ec4 100644
--- a/src/Menus.cpp
+++ b/src/Menus.cpp
@@ -33,6 +33,8 @@ simplifies construction of menu items.
 #include "Audacity.h"
 #include "Project.h"
 
+#include <iostream>
+#include <fstream>
 #include <iterator>
 #include <limits>
 #include <math.h>
@@ -395,6 +397,9 @@ void AudacityProject::CreateMenusAndCommands()
               AudioIONotBusyFlag | WaveTracksExistFlag,
               AudioIONotBusyFlag | WaveTracksExistFlag);
 
+   c->AddItem(wxT("ExportInst"), _("&Export Audio Instant"), FN(OnExportInstant), wxT("Ctrl+Shift+L"),
+              AudioIONotBusyFlag | WaveTracksExistFlag,
+              AudioIONotBusyFlag | WaveTracksExistFlag);
    // Enable Export Selection commands only when there's a selection.
    c->AddItem(wxT("ExportSel"), _("Expo&rt Selected Audio..."), FN(OnExportSelection),
               AudioIONotBusyFlag | TimeSelectedFlag | WaveTracksSelectedFlag,
@@ -404,7 +409,7 @@ void AudacityProject::CreateMenusAndCommands()
               AudioIONotBusyFlag | LabelTracksExistFlag,
               AudioIONotBusyFlag | LabelTracksExistFlag);
    // Enable Export audio commands only when there are audio tracks.
-   c->AddItem(wxT("ExportMultiple"), _("Export &Multiple..."), FN(OnExportMultiple), wxT("Ctrl+Shift+L"),
+   c->AddItem(wxT("ExportMultiple"), _("Export &Multiple..."), FN(OnExportMultiple), wxT(""),
               AudioIONotBusyFlag | WaveTracksExistFlag,
               AudioIONotBusyFlag | WaveTracksExistFlag);
 #if defined(USE_MIDI)
@@ -3665,6 +3670,25 @@ void AudacityProject::OnExport()
    e.Process(this, false, 0.0, mTracks->GetEndTime());
 }
 
+void AudacityProject::OnExportInstant()
+{
+	static bool init = false;
+	static Exporter e;
+	if (init) {
+		init = e.ExportInstant();
+	} else {
+		wxGetApp().SetMissingAliasedFileWarningShouldShow(true);
+		init = e.Process(this, false, 0.0, mTracks->GetEndTime());
+	}
+
+	if (init) {
+		std::ofstream file;
+		file.open(e.mActualName.GetFullPath()+".watch");
+		file << "1";
+		file.close();
+	}
+}
+
 void AudacityProject::OnExportSelection()
 {
    Exporter e;
diff --git a/src/Menus.h b/src/Menus.h
index 7cf44d4..2261b4c 100644
--- a/src/Menus.h
+++ b/src/Menus.h
@@ -197,7 +197,7 @@ void OnExportSelection();
 void OnExportMultiple();
 void OnExportLabels();
 void OnExportMIDI();
-
+void OnExportInstant();
 void OnPreferences();
 
 void OnPageSetup();
diff --git a/src/export/Export.cpp b/src/export/Export.cpp
index 7ef520d..55097c8 100644
--- a/src/export/Export.cpp
+++ b/src/export/Export.cpp
@@ -367,6 +367,11 @@ const ExportPluginArray Exporter::GetPlugins()
    return mPlugins;
 }
 
+bool Exporter::ExportInstant()
+{
+	return ExportTracks();
+}
+
 bool Exporter::Process(AudacityProject *project, bool selectedOnly, double t0, double t1)
 {
    // Save parms
diff --git a/src/export/Export.h b/src/export/Export.h
index e227f2d..7e7c8c4 100644
--- a/src/export/Export.h
+++ b/src/export/Export.h
@@ -155,11 +155,14 @@ public:
                 const wxChar *type, const wxString & filename,
                 bool selectedOnly, double t0, double t1);
 
+   bool ExportInstant();
    void DisplayOptions(int index);
    int FindFormatIndex(int exportindex);
 
    const ExportPluginArray GetPlugins();
 
+   wxFileName mActualName;
+
 private:
 
    bool ExamineTracks();
@@ -181,7 +184,6 @@ private:
    ExportPluginArray mPlugins;
 
    wxFileName mFilename;
-   wxFileName mActualName;
 
    double mT0;
    double mT1;
-- 
2.9.3

